#ifndef _KINOTIFY_H_
#define _KINOTIFY_H_

#include <QtCore/QFlags>

namespace KInotify {
    /**
     * Watch mode
     */
    enum WatchMode {
	WatchAccess = 0x00000001, /**< File was accessed (read, compare inotify's IN_ACCESS) */
	WatchAttributeChange = 0x00000004, /**< Metadata changed (permissions, timestamps, extended attributes, etc., compare inotify's IN_ATTRIB) */
	WatchCloseWrite = 0x00000008, /**< File opened for writing was closed (compare inotify's IN_CLOSE_WRITE) */
	WatchCloseRead = 0x00000010, /**< File not opened for writing was closed (compare inotify's IN_CLOSE_NOWRITE) */
	WatchCreate = 0x00000100, /** File/directory created in watched directory (compare inotify's IN_CREATE) */
	WatchDelete = 0x00000200, /**< File/directory deleted from watched directory (compare inotify's IN_DELETE) */
	WatchDeleteSelf = 0x00000400, /**< Watched file/directory was itself deleted (compare inotify's IN_DELETE_SELF) */
	WatchModify = 0x00000002, /**< File was modified (compare inotify's IN_MODIFY) */
	WatchMoveSelf = 0x00000800, /**< Watched file/directory was itself moved (compare inotify's IN_MOVE_SELF) */
	WatchMoveFrom = 0x00000040, /**< File moved out of watched directory (compare inotify's IN_MOVED_FROM) */
	WatchMoveTo = 0x00000080, /**< File moved into watched directory (compare inotify's IN_MOVED_TO) */
	WatchOpen = 0x00000020, /**< File was opened (compare inotify's IN_OPEN) */
	WatchMove = ( WatchMoveFrom|WatchMoveTo),
	WatchAll = ( WatchAccess|
		     WatchAttributeChange|
		     WatchCloseWrite|
		     WatchCloseRead|
		     WatchCreate|
		     WatchDelete|
		     WatchDeleteSelf|
		     WatchModify|
		     WatchMoveSelf|
		     WatchMoveFrom|
		     WatchMoveTo|
		     WatchOpen )
    };
    Q_DECLARE_FLAGS(WatchModes, WatchMode)


    enum WatchFlag {
	FlagOnlyDir = 0x01000000, /**< Only watch the path if it is a directory (IN_ONLYDIR) */
	FlagDoNotFollow = 0x02000000, /**< Don't follow a sym link (IN_DONT_FOLLOW) */
	FlagOneShot = 0x80000000 /**< Only send event once (IN_ONESHOT) */
    };
    Q_DECLARE_FLAGS(WatchFlags, WatchFlag)


    /**
     * inotify events that can occur
     */
    enum WatchEvent {
	EventAccess = 0x00000001, /**< File was accessed (read, compare inotify's IN_ACCESS) */
	EventAttributeChange = 0x00000004, /**< Metadata changed (permissions, timestamps, extended attributes, etc., compare inotify's IN_ATTRIB) */
	EventCloseWrite = 0x00000008, /**< File opened for writing was closed (compare inotify's IN_CLOSE_WRITE) */
	EventCloseRead = 0x00000010, /**< File not opened for writing was closed (compare inotify's IN_CLOSE_NOWRITE) */
	EventCreate = 0x00000100, /** File/directory created in watched directory (compare inotify's IN_CREATE) */
	EventDelete = 0x00000200, /**< File/directory deleted from watched directory (compare inotify's IN_DELETE) */
	EventDeleteSelf = 0x00000400, /**< Watched file/directory was itself deleted (compare inotify's IN_DELETE_SELF) */
	EventModify = 0x00000002, /**< File was modified (compare inotify's IN_MODIFY) */
	EventMoveSelf = 0x00000800, /**< Watched file/directory was itself moved (compare inotify's IN_MOVE_SELF) */
	EventMoveFrom = 0x00000040, /**< File moved out of watched directory (compare inotify's IN_MOVED_FROM) */
	EventMoveTo = 0x00000080, /**< File moved into watched directory (compare inotify's IN_MOVED_TO) */
	EventOpen = 0x00000020, /**< File was opened (compare inotify's IN_OPEN) */
	EventUnmount = 0x00002000, /**< Backing fs was unmounted (compare inotify's IN_UNMOUNT) */
	EventQueueOverflow = 0x00004000, /**< Event queued overflowed (compare inotify's IN_Q_OVERFLOW) */
	EventIgnored = 0x00008000 /**< File was ignored (compare inotify's IN_IGNORED) */
    };
    Q_DECLARE_FLAGS(WatchEvents, WatchEvent)
}

#endif
