
#ifndef _KINOTIFY_DIR_WATCH_H_
#define _KINOTIFY_DIR_WATCH_H_

#include <QtCore/QObject>

#include "kinotify.h"
#include "kinotify_export.h"

namespace KInotify {

    class KINOTIFY_EXPORT DirWatch : public QObject
    {
	Q_OBJECT

    public:
	DirWatch( QObject* parent = 0 );
	~DirWatch();

	bool watchingPath( const QString& path );

    public Q_SLOTS:
	/**
	 * WatchMoveSelf is not supported yet as we are missing the path where it has been moved to.
	 * Move information will only be available if both the source and target folders are watched
	 */
	bool addWatch( const QString& path, WatchModes modes, WatchFlags flags = WatchFlags(), bool recursive = false );
	void removeWatch( const QString& path );

    Q_SIGNALS:
	void accessed( const QString& file );
	void attributeChanged( const QString& file );
	void closedWrite( const QString& file );
	void closedRead( const QString& file );
	void created( const QString& file );
	void deleted( const QString& file );
	void modified( const QString& file );

	/**
	 * The moved signal will only be emitted if both the source and target folder
	 * is being watched.
	 */
	void moved( const QString& oldName, const QString& newName );
	void opened( const QString& file );
	void unmounted( const QString& file );
	void queueOverflow();

	/**
	 * Emitted if during updating the internal watch structures (recursive watches)
	 * the inotify user watch limit was reached.
	 * This signal will only be emitted once.
	 */
	void watchUserLimitReached();

    private Q_SLOTS:
	void slotEvent( int );

    private:
	class Private;
	Private* const d;
    };
}

#endif
