/*
   This file is part of the Nepomuk KDE project.
   Copyright (C) 2007 Sebastian Trueg <trueg@kde.org>

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
   License version 2 as published by the Free Software Foundation.

   This library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public License
   along with this library; see the file COPYING.LIB.  If not, write to
   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
   Boston, MA 02110-1301, USA.
 */

#ifndef _NEPOMUK_SEARCH_TERM_H_
#define _NEPOMUK_SEARCH_TERM_H_

#include <QtCore/QList>
#include <QtCore/QSharedDataPointer>

#include <nepomuk/nepomuk_export.h>


namespace Nepomuk {
    namespace Search {
        class NEPOMUK_EXPORT Term
        {
        public:
            /**
             * Constructs an invalid term.
             */
            Term();

            /**
             * Copy constructor.
             */
            Term( const Term& other );

            /**
             * Construct a literal term.
             */
            Term( const QString& value );

            /**
             * Destructor
             */
            ~Term();

            /**
             * Assign another term to this one.
             */
            Term& operator=( const Term& other );

            /**
             * Make the term a literal term.
             */
            Term& operator=( const QString& other );

            /**
             * Each search term has a type.
             */
            // FIXME: Missing: <, >, <=, >=
            enum Type {
                InvalidTerm,    /**< An invalid term does not do anything */
                LiteralTerm,    /**< A literal term is the simplest form: it just matches a word. */
                AndTerm,        /**< Match all of the subterms. */
                OrTerm,         /**< Match one of the subterms. */
                ContainsTerm,   /**< Match a value inside a field. */
                EqualityTerm    /**< A field needs to macth exactly. */
            };

            bool isValid() const;
            Type type() const;
            QString value() const;
            QString field() const;
            QList<Term> subTerms() const;

            void setType( Type );
            void setValue( const QString& );
            void setField( const QString& );
            void setSubTerms( const QList<Term>& );
            void addSubTerm( const Term& );

        private:
            class Private;
            QSharedDataPointer<Private> d; 
        };
    }
}

QDebug operator<<( QDebug, const Nepomuk::Search::Term& );

#endif
